/* 
 * i-scream central monitoring system
 * http://www.i-scream.org
 * Copyright (C) 2000-2002 i-scream
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

//---PACKAGE DECLARATION---
package uk.org.iscream.cms.server.client;

//---IMPORTS---
import uk.org.iscream.cms.server.componentmanager.*;
import uk.org.iscream.cms.server.core.*;
import uk.org.iscream.cms.util.*;
import uk.org.iscream.cms.server.clientinterface.*;

/**
 * A servant for the LocalClient.
 * This represents the Client interface for CORBA
 * clients connecting to the i-scream system on the ClientInterface.
 *
 * The i-scream ClientInterface pumps data over CORBA into the
 * queue, using the recieveXML method.  The MonitorManager
 * then handles pulling the data out of this queue.
 *
 * @author  $Author: tdb $
 * @version $Id: ClientServant.java,v 1.15 2004/08/01 10:40:41 tdb Exp $
 */
class ClientServant extends ClientPOA {

//---FINAL ATTRIBUTES---

    /**
     * The current CVS revision of this class
     */
    public static final String REVISION = "$Revision: 1.15 $";
    
//---STATIC METHODS---

//---CONSTRUCTORS---
    
    /**
     * Construct a new ClientServant, with a given Queue.
     *
     * @param queue The Queue that will link this class to the MonitorManager
     */
    public ClientServant(Queue queue) {
        _queue = queue;
    }

//---PUBLIC METHODS---
    
    /**
     * Adds the inbound data to our queue when the CORBA method is called.
     *
     * @param xml The String of XML data
     */
    public void receiveXML(String xml) {
        _queue.add(xml);
    }

    /**
     * Overrides the {@link java.lang.Object#toString() Object.toString()}
     * method to provide clean logging (every class should have this).
     *
     * This uses the uk.org.iscream.cms.util.FormatName class
     * to format the toString()
     *
     * @return the name of this class and its CVS revision
     */
    public String toString() {
        return FormatName.getName(
            _name,
            getClass().getName(),
            REVISION);
    }

//---PRIVATE METHODS---

//---ACCESSOR/MUTATOR METHODS---

//---ATTRIBUTES---

    /**
     * This is the friendly identifier of the
     * component this class is running in.
     * eg, a Filter may be called "filter1",
     * If this class does not have an owning
     * component,  a name from the configuration
     * can be placed here.  This name could also
     * be changed to null for utility classes.
     */
    private String _name = ClientMain.NAME;

    /**
     * This holds a reference to the
     * system logger that is being used.
     */
    private Logger _logger = ReferenceManager.getInstance().getLogger();

    /**
     * A reference to our Queue to place the inbond data into.
     */
    private Queue _queue;

//---STATIC ATTRIBUTES---

}
